summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorjorlow@chromium.org <jorlow@chromium.org@62dab493-f737-651d-591e-8d6aee1b9529>2011-03-22 23:24:02 +0000
committerjorlow@chromium.org <jorlow@chromium.org@62dab493-f737-651d-591e-8d6aee1b9529>2011-03-22 23:24:02 +0000
commit8303bb1b33a4db1d688d32f9be10976b0b54f209 (patch)
tree01802e7d30e43809b4a8c62a073c11c6037eb8f6 /include
parent6d243ebf79640525a94fab280efeb5a46c994af6 (diff)
downloadleveldb-8303bb1b33a4db1d688d32f9be10976b0b54f209.tar.gz
Pull from upstream.
git-svn-id: https://leveldb.googlecode.com/svn/trunk@14 62dab493-f737-651d-591e-8d6aee1b9529
Diffstat (limited to 'include')
-rw-r--r--include/options.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/options.h b/include/options.h
index 1105570..0b65624 100644
--- a/include/options.h
+++ b/include/options.h
@@ -22,8 +22,8 @@ class WritableFile;
enum CompressionType {
// NOTE: do not change the values of existing entries, as these are
// part of the persistent format on disk.
- kNoCompression = 0x0,
- kLightweightCompression = 0x1,
+ kNoCompression = 0x0,
+ kSnappyCompression = 0x1,
};
// Options to control the behavior of a database (passed to DB::Open)
@@ -122,16 +122,16 @@ struct Options {
// Compress blocks using the specified compression algorithm. This
// parameter can be changed dynamically.
//
// Default: kLightweightCompression, which gives lightweight but fast
// compression.
//
// Typical speeds of kLightweightCompression on an Intel(R) Core(TM)2 2.4GHz:
// ~200-500MB/s compression
// ~400-800MB/s decompression
// Note that these speeds are significantly faster than most
// persistent storage speeds, and therefore it is typically never
// worth switching to kNoCompression. Even if the input data is
// incompressible, the kLightweightCompression implementation will
// efficiently detect that and will switch to uncompressed mode.
CompressionType compression;
@@ -122,16 +122,16 @@ struct Options {
// parameter can be changed dynamically.
//
- // Default: kLightweightCompression, which gives lightweight but fast
+ // Default: kSnappyCompression, which gives lightweight but fast
// compression.
//
@@ -122,16 +122,16 @@ struct Options {
// compression.
//
- // Typical speeds of kLightweightCompression on an Intel(R) Core(TM)2 2.4GHz:
+ // Typical speeds of kSnappyCompression on an Intel(R) Core(TM)2 2.4GHz:
// ~200-500MB/s compression
// ~400-800MB/s decompression
@@ -122,16 +122,16 @@ struct Options {
// persistent storage speeds, and therefore it is typically never
// worth switching to kNoCompression. Even if the input data is
- // incompressible, the kLightweightCompression implementation will
+ // incompressible, the kSnappyCompression implementation will
// efficiently detect that and will switch to uncompressed mode.
CompressionType compression;